@@ -486,11 +486,14 @@ process_page (GtkTreeStore *tree, GHashTable *nodes2offsets,
 	}
 
 	d (if (iter) debug_print (DB_DEBUG, "Have a valid iter, storing for %s\n", node));
+
 	g_hash_table_insert (nodes2iters, g_strdup (node), iter);
 	debug_print (DB_DEBUG, "size: %i\n", g_hash_table_size (nodes2iters));
 
-	tmp = g_strdup_printf ("%i",
-			       node2page (nodes2offsets, offsets2pages, node));
+	/*tmp = g_strdup_printf ("%i",
+	  node2page (nodes2offsets, offsets2pages, node));*/
+	tmp = g_strdup (node);
+	tmp = g_strdelimit (tmp, " ", '_');
 	gtk_tree_store_set (tree, iter,
 			    COLUMN_PAGE_NO, tmp,
 			    COLUMN_PAGE_NAME, node,
@@ -785,7 +788,9 @@ resolve_frag_id (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter,
 		      -1);
   if (g_str_equal (page_name, *xref)) {
     g_free (*xref);
-    *xref = g_strdup (page_no);
+    *xref = g_strdup (page_name);
+    *xref = g_strdelimit (*xref, " ", '_');
+
     g_free (page_name);
     g_free (page_no);
     return TRUE;
@@ -1020,13 +1025,12 @@ info_process_text_notes (xmlNodePtr *node, gchar *content, GtkTreeStore *tree)
 	  if (alt_append) append = alt_append;
 	  else append = alt_append1;
 	}
-	if ((alt_append && alt_append < append) || broken)
+	if ((alt_append && alt_append < append))
 	  append = alt_append;
 	if (alt_append1 && alt_append1 < append)
 	  append = alt_append1;
       }
       append++;
-
       url = g_strndup (*current_real, append - (*current_real));
 
       /* By now, we got 2 things.  First, is append which is the (hopefully)
@@ -1096,7 +1100,6 @@ info_process_text_notes (xmlNodePtr *node, gchar *content, GtkTreeStore *tree)
 
 	    new_url = g_strdup (lurl);
 	    info = strstr (new_url, ".info)");
-	    g_free (lurl);
 	    stripped = g_strndup (new_url, info-new_url);
 	    info +=5;
 	    lurl = g_strconcat (stripped, info, NULL);
@@ -1128,13 +1131,17 @@ info_process_text_notes (xmlNodePtr *node, gchar *content, GtkTreeStore *tree)
 	else {
 	  gchar *spacing = *ulink;
 	  gchar *tmp;
+	  gint count = 0;
 	  while (*spacing == ' ') {
 	    spacing++;
+	    count++;
 	  }
 	  if (spacing != *ulink) {
-	    spacing-=2;
+	    if (count > 1)
+	      spacing-=2;
 	    tmp = g_strndup (*ulink, spacing-*ulink);
-	    spacing+=2;
+	    if (count > 1)
+	      spacing+=2;
 	    xmlNewTextChild (holder, NULL, BAD_CAST "spacing",
 			     BAD_CAST tmp);
 	    g_free (tmp);
