@@ -53,34 +53,24 @@ typedef enum {
 typedef enum {
     YELP_COLOR_FG = 0,
     YELP_COLOR_BG,
+    YELP_COLOR_FG_LIGHT,
     YELP_COLOR_ANCHOR,
-    YELP_COLOR_RULE,
-    YELP_COLOR_GRAY_FG,
+    YELP_COLOR_ANCHOR_VISITED,
     YELP_COLOR_GRAY_BG,
-    YELP_COLOR_GRAY_BG_DARK1,
-    YELP_COLOR_GRAY_BG_DARK2,
-    YELP_COLOR_GRAY_BG_DARK3,
-    YELP_COLOR_SELECTED_FG,
-    YELP_COLOR_SELECTED_BG,
-    YELP_COLOR_SELECTED_BG_DARK1,
-    YELP_COLOR_SELECTED_BG_DARK2,
-    YELP_COLOR_SELECTED_BG_DARK3,
-    YELP_COLOR_ADMON_FG,
-    YELP_COLOR_ADMON_BG,
-    YELP_COLOR_ADMON_BG_DARK1,
-    YELP_COLOR_ADMON_BG_DARK2,
-    YELP_COLOR_ADMON_BG_DARK3,
+    YELP_COLOR_GRAY_BORDER,
+    YELP_COLOR_BLUE_BG,
+    YELP_COLOR_BLUE_BORDER,
+    YELP_COLOR_RED_BG,
+    YELP_COLOR_RED_BORDER,
+    YELP_COLOR_YELLOW_BG,
+    YELP_COLOR_YELLOW_BORDER,
+    YELP_FORCE,
     YELP_NUM_COLORS
 } YelpColorType;
 
 typedef enum {
-    YELP_ICON_BLOCKQUOTE = 0,
-    YELP_ICON_CAUTION,
-    YELP_ICON_IMPORTANT,
-    YELP_ICON_NOTE,
-    YELP_ICON_PROGRAMLISTING,
-    YELP_ICON_TIP,
-    YELP_ICON_WARNING,
+    YELP_ICON_ADMON_PATH,
+    YELP_ICON_ADMON_SIZE,
     YELP_NUM_ICONS
 } YelpIconType;
 
